@@ -15,13 +15,17 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpixmap.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
@@ -117,7 +121,7 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, TQWidget *pa
 
   value = account.value("statementDate");
   if(!value.isEmpty())
-    m_statementDate->setDate(TQDate::fromString(value, Qt::ISODate));
+    m_statementDate->setDate(TQDate::fromString(value, TQt::ISODate));
 
   m_lastStatementDate->setText(TQString());
   if(account.lastReconciliationDate().isValid()) {
@@ -131,16 +135,16 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, TQWidget *pa
   removePage(m_adjustmentTransactionPage);
 
   // connect the signals with the slots
-  connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotReloadEditWidgets()));
-  connect(m_payeeEdit, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SIGNAL(createPayee(const TQString&, TQString&)));
-  connect(m_interestCategoryEdit, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateInterestCategory(const TQString&, TQString&)));
-  connect(m_chargesCategoryEdit, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateChargesCategory(const TQString&, TQString&)));
+  connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(slotReloadEditWidgets()));
+  connect(m_payeeEdit, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SIGNAL(createPayee(const TQString&, TQString&)));
+  connect(m_interestCategoryEdit, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateInterestCategory(const TQString&, TQString&)));
+  connect(m_chargesCategoryEdit, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateChargesCategory(const TQString&, TQString&)));
 
-  connect(m_interestEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_interestCategoryEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_chargesEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_chargesCategoryEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_statementDate, TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotUpdateBalances()));
+  connect(m_interestEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_interestCategoryEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_chargesEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_chargesCategoryEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_statementDate, TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotUpdateBalances()));
 
   slotReloadEditWidgets();
 
@@ -195,24 +199,24 @@ void KEndingBalanceDlg::slotUpdateBalances(void)
   balance = balance * factor;
   endBalance = startBalance = balance;
 
-  tracer.printf("total balance = %s", endBalance.formatMoney("", 2).data());
+  tracer.printf("total balance = %s", endBalance.formatMoney("", 2).local8Bit().data());
 
   for(it = transactionList.begin(); it != transactionList.end(); ++it) {
     const MyMoneySplit& split = (*it).second;
     balance -= split.shares() * factor;
     if((*it).first.postDate() > m_statementDate->date()) {
-      tracer.printf("Reducing balances by %s because postdate of %s/%s(%s) is past statement date", (split.shares() * factor).formatMoney("", 2).data(), (*it).first.id().data(),split.id().data(), (*it).first.postDate().toString(Qt::ISODate).data());
+      tracer.printf("Reducing balances by %s because postdate of %s/%s(%s) is past statement date", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), (*it).first.id().local8Bit().data(),split.id().local8Bit().data(), (*it).first.postDate().toString(TQt::ISODate).local8Bit().data());
       endBalance -= split.shares() * factor;
       startBalance -= split.shares() * factor;
     } else {
       switch(split.reconcileFlag()) {
         case MyMoneySplit::NotReconciled:
-          tracer.printf("Reducing balances by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).data(), (*it).first.id().data(), split.id().data(), (*it).first.postDate().toString(Qt::ISODate).data());
+          tracer.printf("Reducing balances by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), (*it).first.id().local8Bit().data(), split.id().local8Bit().data(), (*it).first.postDate().toString(TQt::ISODate).local8Bit().data());
           endBalance -= split.shares() * factor;
           startBalance -= split.shares() * factor;
           break;
         case MyMoneySplit::Cleared:
-          tracer.printf("Reducing start balance by %s because %s/%s(%s) is cleared", (split.shares() * factor).formatMoney("", 2).data(), (*it).first.id().data(), split.id().data(), (*it).first.postDate().toString(Qt::ISODate).data());
+          tracer.printf("Reducing start balance by %s because %s/%s(%s) is cleared", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), (*it).first.id().local8Bit().data(), split.id().local8Bit().data(), (*it).first.postDate().toString(TQt::ISODate).local8Bit().data());
           startBalance -= split.shares() * factor;
           break;
         default:
@@ -222,8 +226,8 @@ void KEndingBalanceDlg::slotUpdateBalances(void)
   }
   m_previousBalance->setValue(startBalance);
   m_endingBalance->setValue(endBalance);
-  tracer.printf("total balance = %s", endBalance.formatMoney("", 2).data());
-  tracer.printf("start balance = %s", startBalance.formatMoney("", 2).data());
+  tracer.printf("total balance = %s", endBalance.formatMoney("", 2).local8Bit().data());
+  tracer.printf("start balance = %s", startBalance.formatMoney("", 2).local8Bit().data());
 
   m_interestDateEdit->setDate(m_statementDate->date());
   m_chargesDateEdit->setDate(m_statementDate->date());
@@ -362,7 +366,7 @@ bool KEndingBalanceDlg::createTransaction(MyMoneyTransaction &t, const int sign,
     t.modifySplit(s2);
 
   } catch(MyMoneyException *e) {
-    tqDebug("%s", e->what().data());
+    tqDebug(e->what());
     delete e;
     t = MyMoneyTransaction();
     return false;
@@ -404,10 +408,10 @@ KEndingBalanceLoanDlg::KEndingBalanceLoanDlg(const MyMoneyAccount& account, TQWi
   removePage(m_interestChargeCheckings);
 
   // connect the signals with the slots
-  connect(m_amortizationTotalEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_interestTotalEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_accountEdit, TQT_SIGNAL(stateChanged(void)), this, TQT_SLOT(slotCheckPageFinished(void)));
-  connect(m_categoryEdit, TQT_SIGNAL(stateChanged(void)), this, TQT_SLOT(slotCheckPageFinished(void)));
+  connect(m_amortizationTotalEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_interestTotalEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_accountEdit, TQ_SIGNAL(stateChanged(void)), this, TQ_SLOT(slotCheckPageFinished(void)));
+  connect(m_categoryEdit, TQ_SIGNAL(stateChanged(void)), this, TQ_SLOT(slotCheckPageFinished(void)));
 }
 
 KEndingBalanceLoanDlg::~KEndingBalanceLoanDlg()
@@ -590,7 +594,7 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
       t.setPostDate(m_endDateEdit->date());
 
     } catch(MyMoneyException *e) {
-      tqDebug("Unable to create adjustment transaction for loan reconciliation: %s", e->what().data());
+      tqDebug(TQString("Unable to create adjustment transaction for loan reconciliation: %1").arg(e->what()));
       delete e;
       return MyMoneyTransaction();
     }
